//
//  ViewController.m
//  IvrJack.RU01.Demo
//
//  Created by xminnov on 15/4/24.
//  Copyright (c) 2015年 xminnov. All rights reserved.
//

#import "RU01ViewController.h"
#import "EpcRecordTableViewController.h"
#import "IvrJackService.h"
#import "AppDelegate.h"

@interface RU01ViewController ()

@property EpcRecordTableViewController * recordController;
@property IvrJackService *service;
@property bool isReadingEpc;

@end

@implementation RU01ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
    NSArray *weekdayAry = [NSArray arrayWithObjects:@"Sun.", @"Mon.", @"Tues.", @"Wed.", @"Thur.", @"Fri.", @"Sat.", nil];
    NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
    [dateFormatter setDateFormat:NSLocalizedString(@"YYYY-MM-dd  eee", nil)];
    [dateFormatter setShortWeekdaySymbols:weekdayAry];
    [dateFormatter setLocale:[[NSLocale alloc] initWithLocaleIdentifier:@"en_US"]];
    self.lblTime.text = [dateFormatter stringFromDate:[NSDate date]];
    
    [self readerDisconnect];
    self.recordController = [EpcRecordTableViewController new];
    self.recordController.ru01ViewController = self;
    self.recordController.tableView = self.tableRecords;
    self.tableRecords.dataSource = self.recordController;
    self.service = ((AppDelegate *)([UIApplication sharedApplication].delegate)).service;
    
    self.imagePlugout.hidden = YES;
    self.viewReader.hidden = NO;
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)viewWillAppear:(BOOL)animated {
    [self.navigationController setNavigationBarHidden:YES];
}

- (void)viewWillDisappear:(BOOL)animated {
    [self.navigationController setNavigationBarHidden:NO];
}

- (void)readerConnect:(NSString *)deviceSN {
    self.imagePlugout.hidden = YES;
    self.viewReader.hidden = NO;
}

- (void)readerDisconnect {
    self.imagePlugout.hidden = NO;
    self.viewReader.hidden = YES;
    if (self.isReadingEpc) {
        self.btnReadEpc.enabled = YES;
        self.isReadingEpc = NO;
        self.btnSetting.enabled = YES;
        [self.btnReadEpc setTitle:@">>>Start<<<" forState:UIControlStateNormal];
    }
    if (self.navigationController.visibleViewController != self) {
        [self.navigationController popToRootViewControllerAnimated:YES];
    }
}

- (void)readerStatusChange:(IvrJackStatus)status {
    switch (status) {
        case ijsDetecting:
            self.lblStatus.text = @"Device detecting...";
            [self.idcDetecting startAnimating];
            break;
        case ijsRecognized:
            self.lblStatus.text = @"Device connected";
            [self.idcDetecting stopAnimating];
            break;
        case ijsUnRecognized:
            self.lblStatus.text = @"Device unrecognized";
            [self.idcDetecting stopAnimating];
            break;
        case ijsPlugout:
            self.lblStatus.text = @"Device disconnected";
            [self.idcDetecting stopAnimating];
            break;
    }
}

- (void)onReadEpc:(NSString *)epc rssi:(NSString *)rssi{
//    NSLog(@"ru01 view controller onReadEpc");
    NSUInteger count = [self.recordController addEpc:epc rssi:rssi];
    self.lblTotal.text = [NSString stringWithFormat:@"Total: %lu", (unsigned long)count];
}

- (IBAction)onBtnReadEpc:(id)sender {
    if ([self.btnReadEpc.titleLabel.text isEqualToString:@">>>Start<<<"]) {
        [self.idcDetecting startAnimating];
        self.btnReadEpc.enabled = NO;
        self.btnSetting.enabled = NO;
        self.btnInventory.enabled = NO;
        self.isReadingEpc = YES;
        dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_BACKGROUND, 0), ^{
            __block int ret = [self.service setReadEpcStatus:1];
            dispatch_async(dispatch_get_main_queue(), ^{
                [self.idcDetecting stopAnimating];
                self.btnReadEpc.enabled = YES;
                if (ret == 0) {
                    [self.btnReadEpc setTitle:@">>>Stop<<<" forState:UIControlStateNormal];
                    self.lblStatus.text = @"Device start read epc";
                } else {
                    self.lblStatus.text = [NSString stringWithFormat:@"Device start read epc failed: %d", ret];
                    self.btnSetting.enabled = YES;
                    self.isReadingEpc = NO;
                    self.btnInventory.enabled = YES;
                }
            });
        });
    } else {
        [self.idcDetecting startAnimating];
        self.btnReadEpc.enabled = NO;
        dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_BACKGROUND, 0), ^{
            [self.service setReadEpcStatus:0];
            dispatch_async(dispatch_get_main_queue(), ^{
                [self.idcDetecting stopAnimating];
                self.btnReadEpc.enabled = YES;
                self.isReadingEpc = NO;
                self.btnSetting.enabled = YES;
                self.btnInventory.enabled = YES;
                [self.btnReadEpc setTitle:@">>>Start<<<" forState:UIControlStateNormal];
                self.lblStatus.text = @"Device stop read epc";
            });
        });
    }
}

- (IBAction)onBtnClear:(id)sender {
    [self.recordController clearRecords];
    self.lblTotal.text = @"Total: 0";
}

- (IBAction)onBtnInventory:(id)sender{
    self.btnReadEpc.enabled = NO;
    self.btnInventory.enabled = NO;
    self.btnSetting.enabled = NO;
    dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_BACKGROUND, 0),^{
        NSMutableArray *epc = [NSMutableArray array];
        NSMutableArray *rssi  = [NSMutableArray array];
        __block int ret = [self.service inventory:epc rssi:rssi];
        dispatch_async(dispatch_get_main_queue(), ^{
            self.btnReadEpc.enabled = YES;
            self.btnInventory.enabled = YES;
            self.btnSetting.enabled = YES;
            if(ret == 0){
                NSUInteger count = 0;
                for (int i = 0; i < epc.count; i ++) {
                    count = [self.recordController addEpc:epc[i] rssi:rssi[i]];
                }
                self.lblTotal.text = [NSString stringWithFormat:@"Total: %lu", (unsigned long)count];
            }
            else if(ret == INVENTORY_NOTAG){
            [[[UIAlertView alloc] initWithTitle:@"" message:@"No Tag Response" delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil, nil] show];
            }else{
                [[[UIAlertView alloc] initWithTitle:@"" message:@"The reader doesn't support this feature" delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil, nil] show];
            }
        });
    });
}

- (void)accessTagWithEpc:(NSString *)epc {
    if (!self.isReadingEpc) {
        self.selectedEpc = epc;
        [self performSegueWithIdentifier:@"tag access" sender:self];
    }
}

@end
